@@ -10,6 +10,7 @@ from .ariston_api import AristonAPI
 from .const import (
     ConsumptionTimeInterval,
     ConsumptionType,
+    CustomDeviceFeatures,
     DeviceFeatures,
     DeviceAttribute,
     GalevoDeviceAttribute,
@@ -93,6 +94,11 @@ class AristonDevice(ABC):
         """Get device name wrapper"""
         return self.attributes.get(DeviceAttribute.NAME, None)
 
+    @property
+    def has_dhw(self)-> Optional[bool]:
+        """Get device has domestic hot water"""
+        return self.custom_features.get(CustomDeviceFeatures.HAS_DHW, None)
+
     @property
     def dhw_mode_changeable(self) -> Optional[bool]:
         """Get device domestic hot water mode changeable wrapper"""
@@ -107,12 +113,17 @@ class AristonDevice(ABC):
     def firmware_version(self) -> Optional[str]:
         """Get device firmware version wrapper"""
         return self.attributes.get(GalevoDeviceAttribute.FW_VER, None)
-    
+
     @property
     def bus_errors(self) -> list[dict[str, Any]]:
         """Get bus errors list wrapper"""
         return self.bus_errors_list
 
+    @property
+    def hpmp_sys(self) -> Optional[bool]:
+        """Get device heat pump multi power system"""
+        return self.attributes.get(DeviceAttribute.HPMP_SYS, None)
+
     def get_features(self) -> None:
         """Get device features wrapper"""
         self.features = self.api.get_features_for_device(self.gw)
@@ -353,7 +364,7 @@ class AristonDevice(ABC):
 
     def are_device_features_available(
         self,
-        device_features: Optional[list[DeviceFeatures]],
+        device_features: Optional[list[DeviceFeatures | CustomDeviceFeatures | DeviceAttribute]],
         system_types: Optional[list[SystemType]],
         whe_types: Optional[list[WheType]],
     ) -> bool:
@@ -369,6 +380,7 @@ class AristonDevice(ABC):
                 if (
                     self.features.get(str(device_feature)) is not True
                     and self.custom_features.get(str(device_feature)) is not True
+                    and self.attributes.get(str(device_feature)) is not True
                 ):
                     return False
 
